Enum gilrs_core::Error
source · Expand description
Error type which can be returned when creating Gilrs.
Variants
NotImplemented(Gilrs)
Gilrs does not support current platform, but you can use dummy context from this error if gamepad input is not essential.
Other(Box<dyn Error + Send + Sync + 'static>)
Platform specific error.