Struct gilrs_core::Gamepad [−][src]
#[repr(transparent)]pub struct Gamepad { /* fields omitted */ }Expand description
Provides information about gamepad.
Implementations
Returns true if gamepad is connected.
Returns UUID that represents gamepad model.
Returned UUID should be the same as SLD2 uses. If platform does not provide any method to distinguish between gamepad models, nil UUID is returned.
It is recommended to process with the UUID crate.
Use Uuid::from_bytes method to create a Uuid from the returned bytes.
Returns device’s power supply state.
Returns true if force feedback is supported by device,
Returns slice with EvCodes that may appear in button related events.
Returns slice with EvCodes that may appear in axis related events.